@@ -5,10 +5,12 @@
 #  When the Algorithm::KMeans module creates new cluster files,
 #  it automatically delete all previously created such files.
 #  Such files are named ClusterX.dat for X starting with X = 0.
-#  The files temp_* are created by the visualization script.
+#  The files __temp_* are created by the visualization script.
+#  However, when the program terminates properly, it should 
+#  automatically delete those files.
 
 
 unlink glob "Cluster*.dat";
 
-unlink glob "temp_*";
+unlink glob "__temp_*";
 
